******************************************************************************************************
* Programme d'exemple de programmation en assembleur HC11 pour UMPS                                  *
* Le dernier octet transitant par la spi est affich sur les afficheurs 7 segments                   *
* La carte communique avec le PC en ASCII. Donc pour envoyer $01 on envoie de code ASCII de 1 et     *
* celui de 0                                                                                         *           
******************************************************************************************************
* Cartographie mmoire : (j'utilise un 68HC11F1 en mode tendu)
*            +---------------+
*       $FFFF|   EPROM       |     il y a 32KO de RAM et autant d'EPROM
*	     |  vecteur      |
*	     |d'interruption |
*       $FE00|               |
*	     +---------------+
*	$FDFF|   EPROM       |
*            |  programme    |
*       $8000| et constante  |
*            +---------------+
*       $7FFF|     RAM       |
*            |               |
*       $18FF|               |
*            +---------------+
*       $17FF|   Afficheur   |     J'ai configurer CSIO1 pour mettre un afficheur 7 segments
*	     | 7 segments    |
*            +---------------+
*       $105F|   registre    |
*            |   interne     |
*       $1000|               |
*            +---------------+
*       $0FFF|     RAM       |
*	     |               |
*	$0000|               |
*            +---------------+
******* Vecteurs d'interruptions :
*       SCI     : $FFD6 et $FFD7
*       RTI     : $FFF0 et $FFF1
*       reset   : $FFFE et $FFFF 

TPE              EQU    $5FFF              ;Au lieu d'crire $5FFF un peut partout dans le programme, j'cris TPE
                                           ;cela permet de le modifi ici si besoin (c'est long de le remplacer dans tout le programme

* Variables :                              ;cette ligne est inutile
                 ORG     $0000             ; partir d'ici, on crit dans la ram (adresse $0000, voir cartographie mmoire)

OctetAffich	 rmb     1		   ;octet  afficher sur les afficheurs 7 segments
                                           ;l'instruction RMB rserve un certain nombre d'octet en mmoire. Ici, c'est 1. A chaque fois que l'on essaye d'crire  l'adresse OctetAffich, on accde  l'adresse $0000
OctetAffU        rmb     1                 ;Octet prt  tre affich sur l'afficheur des units
                                           ;maintenent on est  $0001
OctetAffD        rmb     1                 ;Octet prt  tre affich sur l'afficheur des dizaines
Afficheur        rmb     1                 ;numro de l'afficheur qui va tre actif
Octet_Sci        rmb     1                 ;emplacement mmoire de l'octet transitant sur la liaison SCI
Octet_Spi        rmb     1                 ;emplacement mmoire de l'octet transitant sur la liaison SPI
VitMot           rmb     2		   ;vitesse du moteur
                                           ;ici on rserve 2 octets
OctetAscii	 rmb     1		   ;variable pour la transition en ASCII
Octet1	 	 rmb	 1		   ;variable pour la transition en ASCII
Octet2	 	 rmb	 1		   ;variable pour la transition en ASCII
Instruc          rmb     2		   ;les instruction (prendre le relev de courbes...)


                 ORG     $8000             ;on place le programme en dbut d'EPROM
* Programme Principal :
Debut            LDS     #$7FFF            ;Position de la pile en fin de RAM avant les registres interne

                 ldaa    #%11000101
                 staa    CSCTL             ;initialisation du registre CSCTL
                 ldaa    #%00000000
                 staa    CSGADR            ;initialisation du registre CSGADR (pas de csio2, csio1 actif  l'tat haut, 32K de prog et de ram
		 ldaa	 #%00000001
                 staa    CSGSIZ            ;initialisation du registre CSGSIZ
                 ldaa    #%11000000
                 staa    CSSTRH            ;initialisation du registre CSSTRH (voir la documentation constructeur du hc11f1 l'utiliter de ces registres)

                 jsr     Init_Princ        ;initialise les port et les registres
                                           ;jsr est un appel  un sous programme
                 jsr     Init_Spi          ;initialise la liaison SPI
		 jsr     Init_Sci          ;initialise la liaison SCI (format 8bits sans Wakeup)
                 CLI                       ;active toutes les interruptions autotises (RTI)

Boucle1          jsr     ReceptSCI         ;on dialogue avec le PC
                 ldaa    Instruc           ;on regarde quelle action on doit effectuer (inutile ici puisque ce programme effectue une seule action)
                 beq     Boucle1
                 cmpa    #$01
                 bne     BouE1
                 clr     Instruc
                 jsr     DialEs1
BouE1            bra     Boucle1

* Sous-Programmes : Init_Princ
Init_Princ       ldaa    #%11111111
                 staa    DDRA              ;initialisation des entres/sorties du port A
                 ldaa    #$FF
                 staa    Porta
                 ldaa    #%00011010
                 staa    DDRD              ;initialisation du port D
                 ldaa    #%00011100
                 staa    PORTD             ;toutes les sorties de la liaison SPI sont  l'tat haut
                 ldaa    TabAff
                 staa    OctetAffU
                 adda    #$80
                 staa    OctetAffD
                 ldaa    #$01
                 staa    PACTL
                 ldaa    #$40
                 staa    TMSK2
                 ldaa    #$ff
                 staa    $1060             ;extinction de l'afficheur
                 rts

* Sous-Programme : DialEs1
DialEs1          LDX     #es1		   ;on veut le moteur en marche
                 clr     Octet_Spi         ;on communique avec es1
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$02
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    VitMot            ;l'octet  transmettre est dans VitMot
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    VitMot+1
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi    ;les octets sont envoys
                 RTS

* Fentre Programme : Affiche
Affiche		 pshb
                 pshx    		   ;on va affiche l'octet sur les afficheurs
                 clra                      ;on efface les octets de poids fort de d
                 ldab    OctetAffich       ;on traite l'octet  afficher pour le mettre sur 2 afficheurs
                 andb    #$0F     	   
		 addd	 #TabAff+1	   
		 xgdx                      ;l'adresse de l'octet  afficher est mise dans x
		 ldaa	 0,x		   
                 staa    OctetAffU
                 clra                      ;on efface les octets de poids fort de d
                 ldab    OctetAffich       ;on traite l'octet  afficher pour le mettre sur 2 afficheurs
                 andb    #$F0      	   
                 LSRB                      
                 LSRB                      
                 LSRB                      
                 LSRB                      
		 addd	 #TabAff+1	   
		 xgdx			   
		 ldaa	 0,x		   
                 oraa    #%10000000        ;on slectionne l'autre afficheur
                 staa    OctetAffD
		 pulx                      ;on restaure tous les accumulateurs
		 pulb
                 rts

* Fentre Programme : Int_RTI
Int_RTI          LDAA    #$40
                 STAA    TFLG2             ;remise  0 de RTIF en crivant un 1 par dessus 
                 TST     Afficheur         ;ce programme s'excute  interval rgulier et change l'afficheur allum
                 BNE     Diz
                 INC     Afficheur
                 LDAA    OctetAffU
                 STAA    $1060
                 RTI                       ;RTI indique la fin d'un programme d'interruption
Diz              CLR     Afficheur
                 LDAA    OctetAffD
                 STAA    $1060
                 RTI


* Fentre Programme : Init_Spi
Init_Spi         LDAA    noes
                 STAA    PORTA             ;tous les SSxbar sont  l'tat haut
                 LDAA    #%00011010        ;SS/, SCK, MOSI, MISO, TxD, RxD
                 STAA    DDRD              ;initialisation du port D
                 LDAA    #%01010101
                 STAA    SPCR              ;pas d'interruption, port D avec soRTIe CMOS, mode matre, horloge sur front descendant et pas retarde, 1Mb/s
                 RTS

* Fentre Programme : Emet_Octet_Spi
Emet_Octet_Spi   LDAA    0,x               ;active l'esclave  slectionner
                 STAA    PORTA             ;il faut l'esclave dans x et l'octet  l'adresse Octet_Spi
                 LDAA    Octet_Spi         ;Quand on communique par la SPI, l'horloge de la spi est active quand le matre envoie un octet
                 STAA    SPDR              ;c'est  ce moment que l'esclave lui envoie son octet (au moment de la communication les registres SPDR des deux micro sont changs)
                 JSR     Tempo   
                 LDAA    SPSR              ; Lecture successive de SPSR et SPDR pour mettre SPIF  0 (page 163)
                 LDAA    SPDR
                 staa    Octet_Spi         ;l'octet reu est dans Octet_Spi
                 staa    OctetAffich       ;et on le met pour tre affich
                 jsr     Affiche
                 RTS

* Fentre Programme : Tempo
Tempo8us         PSHA                      ;un petit programme de temporisation
                 LDAA    #$55
Encore           ldab    spsr
                 DECA
                 Beq     DecrA
                 andb    #$80
                 cmpb    #$80
                 bne     Encore
DecrA            PULA
                 RTS

* Fentre Programme : TempoEs
TempoEs          PSHY                      ;un autre
                 LDY     #TPE
DecrY            DEY
                 BNE     DecrY
                 PULY
                 RTS

* Fentre Programme : Init_Sci
Init_Sci         EQU     *
                 LDAA    #%00110000
                 STAA    BAUD              ;Vitesse de 19200 Bauds puisque la carte possde un Quartz de 16 MHz
                 CLR     SCCR1             ;Format 8 bits sans Wakeup
                 ldaa    #%00001100
                 STAA    SCCR2             ;Interruption en rception
                 clr     Instruc
                 RTS
      
* Fentre Programme : Emet_Octet_Sci
Emet_Octet_Sci   PSHB
		 LDAA    Octet_Sci
                 STAA    OctetAscii
		 JSR     ASCII
Attend           LDAB    SCSR              ;l'octet  mettre est  l'adresse Octet_Sci
                 BPL     Attend
                 LDAB    Octet2
                 STAB    SCDR
Attend2          LDAB    SCSR              ;l'octet  mettre est  l'adresse Octet_Sci
                 BPL     Attend2
                 LDAB    Octet1
                 STAB    SCDR
                 PULB
                 RTS

* Fentre Programme : Attend_OctetSci
Attend_OctetSci  LDAA    SCSR
                 ANDA    #%00100000
                 BEQ     Attend_OctetSci
                 LDAA    SCDR              ;l'octet reut est  l'adresse Octet_Sci (poids fort)
                 staa    Octet2
Atten_OctetSci2  LDAA    SCSR
                 ANDA    #%00100000
                 BEQ     Atten_OctetSci2
                 LDAA    SCDR              ;l'octet reut est  l'adresse Octet_Sci (poids faible)
                 staa    Octet1
                 jsr     Ascii4
                 ldaa    OctetAscii
                 staa    Octet_Sci
                 RTS

* Fentre Programme : ASCII4
ASCII4           LDAA   Octet1             ;poids faible
                 cmpa   #$40               ;Ce programme fait l'inverse de ASCII
                 blo    Ascii5
                 suba   #$07
Ascii5           suba   #$30
                 staa   OctetAscii
                 ldaa   Octet2
                 cmpa   #$40
                 blo    Ascii6
                 suba   #$07
Ascii6           suba   #$30
                 lsla
                 lsla
                 lsla
                 lsla
                 adda   OctetAscii
                 staa   OctetAscii
                 rts

* Fentre Programme : ASCII
ASCII            ldaa    OctetAscii	   ;Ce programme prend l'octet dans OctetAscii et le convertit    
		 anda    #%00001111	   ;en ascii avec les donnes de poids faible dans Octet1 et
		 cmpa    #$0A		   ;ceux de poids fort dans Octet2
		 blo	 ASCII2
		 adda    #$07
ASCII2		 adda    #$30
		 staa    Octet1
                 ldaa    OctetAscii
		 anda    #%11110000
		 LSRA
		 LSRA
		 LSRA
		 LSRA
		 cmpa    #$0A
		 blo	 ASCII3
		 adda    #$07
ASCII3		 adda    #$30
		 staa    Octet2
		 rts

* Fentre Programme : ReceptSCI
ReceptSCI        JSR     Attend_OctetSci   ;ce sous programme attend un octet sur la SCI (rs232) et dialogue avec le PC si c'est un octet valide.
                                           ;our cet exemple, j'ai enlev tout une partie du programme pour faire plus simple mais normalement il ragit  une dizaine d'octets diffrents
                 ldaa    Octet_Sci
                 bne     Suite1
                 jsr     Emet_Octet_Sci
                 jsr     Attend_OctetSci
                 ldaa    Octet_Sci
                 staa    WitMot
                 jsr     Attend_OctetSci
                 ldaa    Octet_Sci
                 staa    VitMot+1
                 ldaa    #$01
                 staa    Instruc
                 rts

Suite1           jmp    ReceptSCI          ;normalement, les autres octets pris en compte sont traits ici

* Fentre Mmoire : Tableau d'affichage
TabAff           FCB     %01111111, %01000000, %01111001, %00100100, %00110000, %00011001, %00010010, %00000010 
                 FCB     %01111000, %00000000, %00010000, %00001000, %00000011, %00100111, %00100001, %00000110 
                 FCB     %00001110, %11111111    ;ces donnes sont envoyes sur les afficheurs 7 segments

* Fentre Mmoire : Tableau d'esclave
TabEs
noes             fcb     %11111111         ;ce sont des donnes que l'on envoie sur le port A pour slectionner un esclave et un seul 
es1              fcb     %11111110
es2              fcb     %11111101
es3              fcb     %11111011
es4              fcb     %11110111
es5              fcb     %11101111
es6              fcb     %11011111

                 org     $FFF0
                 FDB     Int_RTI           ;le vecteur de la RTI pointe sur le programme d'interruption du timer

                 org     $FFFE
                 FDB     Debut             ;le vecteur de reset pointe sur le dbut du programme

                 END                       ;Fichier des instructions
