******************************************************************************************************
* date : 17 juin 2002            Version : 3.1                                                       *
* Titre de projet et nom de fichier : module2.prj , module2.asm                                      *
* description des entres/sorties :                                                                  *
* entres :                                                                                          *
* sorties :                                                                                          *
* Description : Programme qui gre la liaison SCI avec le PC, la liaison SPI avec les esclaves,      *
*               et affiche sur un afficheur 7 segments le dernier octet transmit sur la              *
*               liaison SPI                                                                          *
******************************************************************************************************
* Cartographie mmoire :
*            +---------------+
*       $FFFF|   EPROM       |
*	     |  vecteur      |
*	     |d'interruption |
*       $FE00|               |
*	     +---------------+
*	$FDFF|   EPROM       |
*            |  programme    |
*       $8000| et constante  |
*            +---------------+
*       $7FFF|     RAM       |
*            |               |
*       $18FF|               |
*            +---------------+
*       $17FF|   Afficheur   |
*	     | 7 segments    |
*            +---------------+
*       $105F|   registre    |
*            |   interne     |
*       $1000|               |
*            +---------------+
*       $0FFF|     RAM       |
*	     |               |
*	$0000|               |
*            +---------------+
******* Vecteurs d'interruptions :
*       SCI     : $FFD6 et $FFD7
*       RTI     : $FFF0 et $FFF1
*       reset   : $FFFE et $FFFF 

* Equivalents :

TPE              EQU    $5FFF              ;emplacement mmoire du temps  attendre pour la rponse des esclaves

* Variables :
                 ORG     $0000

* Fentre Registres : Mmoire
OctetAffich	 rmb     1		   ;octet  afficher sur les afficheurs 7 segments
OctetAffU        rmb     1                 ;Octet prt  tre affich sur l'afficheur des units
OctetAffD        rmb     1                 ;Octet prt  tre affich sur l'afficheur des dizaines
Afficheur        rmb     1                 ;numro de l'afficheur qui va tre actif
Word_Sci         rmb     2                 ;emplacement mmoire du mot transitant sur la liaison SCI
Octet_Sci        rmb     1                 ;emplacement mmoire de l'octet transitant sur la liaison SCI
Octet_Spi        rmb     1                 ;emplacement mmoire de l'octet transitant sur la liaison SPI
Heure            rmb     1                 ;emplacement mmoire de l'heure
Minute           rmb     1                 ;emplacement mmoire des minutes
Etat_Es1         rmb     1                 ;tat de l'esclave 1 (moteur  courant continu ou turbine)
Etat_Es2         rmb     1                 ;tat de l'esclave 2 (pression et ronflement)
Etat_Es3         rmb     1                 ;tat de l'esclave 3 (horloge temps relle)
Etat_Es4         rmb     1                 ;tat de l'esclave 4 (sauvegarde des donnes)
Etat_Es5         rmb     1                 ;tat de l'esclave 5 (liaison infrarouge)
Etat_Es6         rmb     1                 ;tat de l'esclave 6 (alimentation)
Pression         rmb     1		   ;valeur de la pression
Ronflement       rmb     1		   ;valeur du ronflement
VitMot           rmb     2		   ;vitesse du moteur
AdreSauvLire     rmb     2		   ;adresse de l'octet sauvegarder ( lire)
OctSauvLire      rmb     1		   ;octet sauvegarder lu
AdreSauvEcr      rmb     2		   ;adresse de l'octet  sauvegarder
OctSauvEcr       rmb     1		   ;octet  sauvegarder
OctetEs5         rmb     1		   ;octet  transmettre par la liaison infrarouge
TensionAlim      rmb     1		   ;valeur de la tension d'alimentation (es9)
OctetAscii	 rmb     1		   ;variable pour la transition en ASCII
Octet1	 	 rmb	 1		   ;variable pour la transition en ASCII
Octet2	 	 rmb	 1		   ;variable pour la transition en ASCII
Instruc          rmb     2		   ;les instruction (prendre le relev de courbes...)


                 ORG     $8000
* Programme Principal :
* Fentre Programme : Debut
Debut            LDS     #$7FFF            ;Position de la pile en RAM avant les registre interne

                 ldaa    #%11000101
                 staa    CSCTL             ;initialisation du registre CSCTL
                 ldaa    #%00000000
                 staa    CSGADR            ;initialisation du registre CSGADR (pas de csio2, csio1 actif  l'tat haut, 32K de prog et de ram
		 ldaa	 #%00000001
                 staa    CSGSIZ            ;initialisation du registre CSGSIZ
                 ldaa    #%11000000
                 staa    CSSTRH            ;initialisation du registre CSSTRH

                 jsr     Init_Princ        ;initialise les port et les registres
                 jsr     Init_Spi          ;initialise la liaison SPI
		 jsr     Init_Sci          ;initialise la liaison SCI (format 8bits sans Wakeup)
                 CLI                       ;autorise toutes les interruptions (RTI)

Boucle1          jsr     ReceptSCI
                 ldaa    Instruc
                 beq     Boucle1
                 cmpa    #$01
                 bne     BouE1
                 clr     Instruc
                 jsr     DialEs1
                 bra     Boucle1
BouE1            cmpa    #$02
                 bne     BouE2
                 clr     Instruc
                 jsr     StopEs1
                 bra     Boucle1

* Fentre Programme : Principal2
BouE2            cmpa    #$03
                 bne     BouE3
                 clr     Instruc
                 jsr     PresRonfEs2
                 ldaa    Ronflement
                 staa    Word_Sci
                 ldaa    Pression
                 staa    Word_Sci+1
                 jsr     Emet_Word_Sci
                 bra     Boucle1
BouE3            cmpa    #$04
                 bne     BouE4
                 clr     Instruc
                 jsr     Heures
                 ldaa    Heure
                 staa    Octet_Sci
                 jsr     Emet_Octet_Sci
                 ldaa    Minute
                 staa    Octet_Sci
                 jsr     Emet_Octet_Sci
                 bra     Boucle1

* Fentre Programme : Principal3
BouE4            cmpa    #$05
                 bne     BouE5
                 clr     Instruc
                 jsr     LireEs4
                 ldaa    OctSauvLire
                 staa    Octet_Sci
                 jsr     Emet_Octet_Sci
                 jmp     Boucle1
BouE5            cmpa    #$06
                 bne     BouE6
                 clr     Instruc
                 jsr     EcrEs4
                 jmp     Boucle1

* Fentre Programme : Principal4
BouE6            cmpa    #$07
                 bne     BouE7
                 clr     Instruc
                 jsr     EmetEs5
                 jmp     Boucle1
BouE7            cmpa    #$08
                 bne     BouE8
                 clr     Instruc
                 jsr     AlimEs6
                 jmp     Boucle1
BouE8            cmpa    #$09
                 bne     BouEs9
                 clr     Instruc
                 jsr     ActEtat
                 ldaa    Etat_Es1
                 staa    Word_Sci
                 ldaa    Etat_Es2
                 staa    Word_Sci+1
                 jsr     Emet_Word_Sci
                 ldaa    Etat_Es3
                 staa    Word_Sci
                 ldaa    Etat_Es4
                 staa    Word_Sci+1
                 jsr     Emet_Word_Sci
                 ldaa    Etat_Es5
                 staa    Word_Sci
                 ldaa    Etat_Es6
                 staa    Word_Sci+1
                 jsr     Emet_Word_Sci
                 jmp     Boucle1

* Fentre Programme : Principal5
BouEs9           cmpa    #$0A
                 beq     AutS
                 jmp     Boucle1
AutS             pshb
                 clr     Instruc
                 ldab    #$30
BouEs10          ldaa    #$00
                 staa    OctetAffU
                 ldaa    #$80
                 staa    OctetAffD
                 ldaa    es1
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es2
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es3
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es4
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es5
                 staa    PortA
                 jsr     TempoEs
                 ldaa    #$7F
                 staa    OctetAffU
                 ldaa    #$FF
                 staa    OctetAffD
                 ldaa    es6
                 staa    PortA
                 jsr     TempoEs

* Fentre Programme : Principal6
                 ldaa    es6
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es5
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es4
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es3
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es2
                 staa    PortA
                 jsr     TempoEs
                 ldaa    es1
                 staa    PortA
                 jsr     TempoEs
                 ldaa    #$00
                 staa    OctetAffU
                 ldaa    #$80
                 staa    OctetAffD
                 decb
                 bne     Autre
                 ldaa    noes
                 staa    PortA
                 ldaa    #$7F
                 staa    OctetAffD
                 ldaa    #$FF
                 staa    OctetAffU
                 pulb
                 jmp     Boucle1

Autre            jmp     BouEs10

* Sous-Programmes :
* Fentre Programme : Init_Princ
Init_Princ       ldaa    #%11111111
                 staa    DDRA              ;initialisation des entres/sorties du port A
                 ldaa    #$FF
                 staa    Porta
                 ldaa    #%00011010
                 staa    DDRD              ;initialisation du port D
                 ldaa    #%00011100
                 staa    PORTD             ;toutes les sorties de la liaison SPI sont  l'tat haut
                 ldaa    TabAff
                 staa    OctetAffU
                 adda    #$80
                 staa    OctetAffD
                 ldaa    #$01
                 staa    PACTL
                 ldaa    #$40
                 staa    TMSK2
                 ldaa    #$ff
                 staa    $1060             ;extinction de l'afficheur
                 rts

* Fentre Programme : DialEs1
DialEs1          LDX     #es1		   ;on veut le moteur en marche
                 clr     Octet_Spi         ;on communique avec es1
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$02
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es1
                 LDAA    VitMot            ;l'octet  transmettre est dans VitMot
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    VitMot+1
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi    ;les octets sont envoys
                 RTS

* Fentre Programme : StopEs1
StopEs1          LDX     #es1		   ;on veut arrter le moteur
                 clr     Octet_Spi         ;on communique avec es1
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es1
                 RTS

* Fentre Programme : PresRonfEs2
PresRonfEs2      LDX     #es2		   
                 clr     Octet_Spi         ;on communique avec es2
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01              ;on veut lire la pression
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es2
                 LDAA    #$02              ;on veut lire le ronflement
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Pression          ;Le rsultat est dans Pression
                 clr     Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Ronflement        ;le rsultat est dans Ronflement
                 RTS

* Fentre Programme : Heures
Heures           LDX     #es3		   ;on va activer l'esclave 3 (horloge temps relle)
                 clr     Octet_Spi
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es3
                 LDAA    #$02
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Heure
                 clr     Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Minute
                 RTS

* Fentre Programme : LireEs4
LireEs4          LDX     #es4		   ;on veut lire une donne sauvegardes
                 clr     Octet_Spi         ;on communique avec l'esclave 4
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es4
                 LDAA    AdreSauvLire  
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    AdreSauvLire+1
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 clr     Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    OctSauvLire
                 RTS

* Fentre Programme : EcrEs4
EcrEs4           LDX     #es4		   ;on veut crire une donne a sauvegarder
                 clr     Octet_Spi         ;on communique avec l'esclave 4
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es4
                 LDAA    AdreSauvEcr  
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    AdreSauvEcr+1
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    OctSauvEcr
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 RTS

* Fentre Programme : EmetEs5
EmetEs5          LDX     #es5		   ;on emet un octet par la liaison infrarouge
                 clr     Octet_Spi         ;on communique avec l'esclave 5
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 LDAA    Octet_Spi
                 STAA    Etat_Es5
                 LDAA    OctetEs5  
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 RTS

* Fentre Programme : AlimEs6
AlimEs6          LDX     #es6		   ;changement de la tension d'alimentation
                 clr     Octet_Spi         ;on communique avec l'esclave 6
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi    ;l'octet est envoy
                 LDAA    #$01
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 jsr     TempoEs
                 jsr     TempoEs
                 LDAA    Octet_Spi
                 STAA    Etat_Es6
                 LDAA    TensionAlim  
                 STAA    Octet_Spi
                 JSR     TempoEs
                 JSR     TempoEs
                 JSR     Emet_Octet_Spi
                 RTS

* Fentre Programme : ActEtat
ActEtat          ldx     #es1
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es1
                 ldx     #es2
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es2
                 ldx     #es3
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es3
                 ldx     #es4
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es4

* Fentre Programme : ActEtat2
                 ldx     #es5
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es5
                 ldx     #es6
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 jsr     TempoEs
                 clr     Octet_Spi
                 jsr     Emet_Octet_Spi
                 ldaa    Octet_Spi
                 staa    Etat_Es6
                 rts

* Fentre Programme : Affiche
Affiche		 pshb
                 pshx    		    ;on va affiche l'octet sur les afficheurs
                 clra                      ;on efface les octets de poids fort de d
                 ldab    OctetAffich       ;on traite l'octet  afficher pour le mettre sur 2 afficheurs
                 andb    #$0F     	   
		 addd	 #TabAff+1	   
		 xgdx                      ;l'adresse de l'octet  afficher est mise dans x
		 ldaa	 0,x		   
                 staa    OctetAffU
                 clra                      ;on efface les octets de poids fort de d
                 ldab    OctetAffich       ;on traite l'octet  afficher pour le mettre sur 2 afficheurs
                 andb    #$F0      	   
                 LSRB                      
                 LSRB                      
                 LSRB                      
                 LSRB                      
		 addd	 #TabAff+1	   
		 xgdx			   
		 ldaa	 0,x		   
                 oraa    #%10000000        ;on slectionne l'autre afficheur
                 staa    OctetAffD
		 pulx                      ;on restaure tous les accumulateurs
		 pulb
                 rts

* Fentre Programme : Int_RTI
Int_RTI          LDAA    #$40
                 STAA    TFLG2             ; remise  0 de RTIF en crivant un 1 par dessus (page )
                 TST     Afficheur
                 BNE     Diz
                 INC     Afficheur
                 LDAA    OctetAffU
                 STAA    $1060
                 RTI
Diz              CLR     Afficheur
                 LDAA    OctetAffD
                 STAA    $1060
                 RTI


* Fentre Programme : Init_Spi
Init_Spi         EQU     *
                 LDAA    noes
                 STAA    PORTA             ;tous les SSxbar sont  l'tat haut
                 LDAA    #%00011010        ;  SS/, SCK, MOSI, MISO, TxD, RxD
                 STAA    DDRD              ;initialisation du port D
                 LDAA    #%01010101
                 STAA    SPCR              ;pas d'interruption, port D avec soRTIe CMOS, mode matre, horloge sur front descendant et pas retarde, 1Mb/s
                 RTS

* Fentre Programme : Emet_Octet_Spi
Emet_Octet_Spi   LDAA    0,x               ;active l'esclave  slectionner
                 STAA    PORTA             ;il faut l'esclave dans x et l'octet  l'adresse Octet_Spi
                 LDAA    Octet_Spi
                 STAA    SPDR
                 JSR     Tempo8us          ;8us
                 LDAA    SPSR              ; Lecture successive de SPSR et SPDR pour mettre SPIF  0 (page 163)
                 LDAA    SPDR
                 staa    Octet_Spi         ;l'octet reu est dans Octet_Spi
                 staa    OctetAffich       ;et on le met pour tre affich
                 jsr     Affiche
                 RTS

* Fentre Programme : Tempo8us
Tempo8us         EQU     *
                 PSHA
                 LDAA    #$55
Encore           ldab    spsr
                 DECA
                 Beq     DecrA
                 andb    #$80
                 cmpb    #$80
                 bne     Encore
DecrA            PULA
                 RTS

* Fentre Programme : TempoEs
TempoEs          EQU     *
                 PSHY
                 LDY     #TPE
DecrY            DEY
                 BNE     DecrY
                 PULY
                 RTS

* Fentre Programme : Init_Sci
Init_Sci         EQU     *
                 LDAA    #%00110000
                 STAA    BAUD              ;Vitesse de 19200 Bauds puisque la carte possde un Quartz de 16 MHz
                 CLR     SCCR1             ;Format 8 bits sans Wakeup
                 ldaa    #%00001100
                 STAA    SCCR2             ;Interruption en rception
                 clr     Instruc
                 RTS

        
* Fentre Programme : Attend_Word_Sci
Attend_Word_Sci  JSR     Attend_OctetSci
		 LDAA    Octet_Sci
		 STAA    Word_Sci
		 JSR     Attend_OctetSci
		 LDAA    Octet_Sci
		 STAA    Word_Sci+1
                 RTS

* Fentre Programme : Emet_Word_Sci
Emet_Word_Sci    LDAA    Word_Sci
		 STAA    Octet_Sci
		 JSR     Emet_Octet_Sci
		 LDAA    Word_Sci+1
		 STAA	 Octet_Sci
		 JSR     Emet_Octet_Sci
		 RTS

* Fentre Programme : Emet_Octet_Sci
Emet_Octet_Sci   PSHB
		 LDAA    Octet_Sci
                 STAA    OctetAscii
		 JSR     ASCII
Attend           LDAB    SCSR              ;l'octet  mettre est  l'adresse Octet_Sci
                 BPL     Attend
                 LDAB    Octet2
                 STAB    SCDR
Attend2          LDAB    SCSR              ;l'octet  mettre est  l'adresse Octet_Sci
                 BPL     Attend2
                 LDAB    Octet1
                 STAB    SCDR
                 PULB
                 RTS

* Fentre Programme : Attend_OctetSci
Attend_OctetSci  LDAA    SCSR
                 ANDA    #%00100000
                 BEQ     Attend_OctetSci
                 LDAA    SCDR              ;l'octet reut est  l'adresse Octet_Sci (poids fort)
                 staa    Octet2
Atten_OctetSci2  LDAA    SCSR
                 ANDA    #%00100000
                 BEQ     Atten_OctetSci2
                 LDAA    SCDR              ;l'octet reut est  l'adresse Octet_Sci (poids faible)
                 staa    Octet1
                 jsr     Ascii4
                 ldaa    OctetAscii
                 staa    Octet_Sci
                 RTS

* Fentre Programme : ASCII4
ASCII4           LDAA   Octet1             ;poids faible
                 cmpa   #$40
                 blo    Ascii5
                 suba   #$07
Ascii5           suba   #$30
                 staa   OctetAscii
                 ldaa   Octet2
                 cmpa   #$40
                 blo    Ascii6
                 suba   #$07
Ascii6           suba   #$30
                 lsla
                 lsla
                 lsla
                 lsla
                 adda   OctetAscii
                 staa   OctetAscii
                 rts

* Fentre Programme : ASCII
ASCII            ldaa    OctetAscii	   ;Ce programme prend l'octet dans OctetAscii et le convertit    
		 anda    #%00001111	   ;en ascii avec les donnes de poids faible dans Octet1 et
		 cmpa    #$0A		   ;ceux de poids fort dans Octet2
		 blo	 ASCII2
		 adda    #$07
ASCII2		 adda    #$30
		 staa    Octet1
                 ldaa    OctetAscii
		 anda    #%11110000
		 LSRA
		 LSRA
		 LSRA
		 LSRA
		 cmpa    #$0A
		 blo	 ASCII3
		 adda    #$07
ASCII3		 adda    #$30
		 staa    Octet2
		 rts

* Fentre Programme : ReceptSCI
ReceptSCI        JSR     Attend_OctetSci
                 ldaa    Octet_Sci
                 bne     Suite1
                 jsr     Emet_Octet_Sci
                 jsr     Attend_Word_Sci
                 ldaa    Word_Sci
                 staa    VitMot
                 ldaa    Word_Sci+1
                 staa    VitMot+1
                 ldaa    #$01
                 staa    Instruc
                 rts

Suite1           cmpa    #$01
                 bne     Suite2
                 jsr     Emet_Octet_Sci
                 ldaa    #$02
                 staa    Instruc
                 rts

Suite2           cmpa    #$02
                 bne     Suite3
                 jsr     Emet_Octet_Sci
                 ldaa    #$03
                 staa    Instruc
                 rts

Suite3           cmpa    #$03
                 bne     Suite4
                 jsr     Emet_Octet_Sci
                 ldaa    #$04
                 staa    Instruc
                 rts

* Fentre Programme : Suite4
Suite4           cmpa    #$04
                 bne     Suite5
                 jsr     Emet_Octet_Sci
                 jsr     Attend_Word_Sci
                 ldaa    Word_Sci
                 staa    AdreSauvLire
                 ldaa    Word_Sci+1
                 staa    AdreSauvLire+1
                 ldaa    #$05
                 staa    Instruc
                 rts

Suite5           cmpa    #$05
                 bne     Suite6
                 jsr     Emet_Octet_Sci
                 jsr     Attend_Word_Sci
                 ldaa    Word_Sci
                 staa    AdreSauvEcr
                 ldaa    Word_Sci+1
                 staa    AdreSauvEcr+1
                 jsr     Attend_OctetSci
                 ldaa    Octet_Sci
                 staa    OctSauvEcr
                 ldaa    #$06
                 staa    Instruc
                 rts

Suite6           cmpa    #$06
                 bne     Suite7
                 jsr     Emet_Octet_Sci
                 jsr     Attend_OctetSci
                 ldaa    Octet_Sci
                 staa    OctetEs5
                 ldaa    #$07
                 staa    Instruc
                 rts

* Fentre Programme : Suite7
Suite7           cmpa    #$07
                 bne     Suite8
                 jsr     Emet_Octet_Sci
                 jsr     Attend_OctetSci
                 ldaa    Octet_Sci
                 staa    TensionAlim
                 ldaa    #$08
                 staa    Instruc
                 rts

Suite8           cmpa   #$08
                 bne    Suite9
                 jsr    Emet_Octet_Sci
                 ldaa   #$09
                 staa   Instruc
                 rts

Suite9           cmpa   #$09
                 bne    SuiteA
                 jsr    Emet_Octet_Sci
                 ldaa   #$0A
                 staa   Instruc
                 rts

SuiteA           jmp    ReceptSCI

* Fentre Mmoire : Tableau d'affichage
TabAff           FCB     %01111111, %01000000, %01111001, %00100100, %00110000, %00011001, %00010010, %00000010 
                 FCB     %01111000, %00000000, %00010000, %00001000, %00000011, %00100111, %00100001, %00000110 
                 FCB     %00001110, %11111111

* Fentre Mmoire : Tableau d'esclave
TabEs
noes             fcb     %11111111
es1              fcb     %11111110
es2              fcb     %11111101
es3              fcb     %11111011
es4              fcb     %11110111
es5              fcb     %11101111
es6              fcb     %11011111


                 org     $FFF0
                 FDB     Int_RTI

                 org     $FFFE
                 FDB     Debut

                 END
